@@ -23,7 +23,7 @@ WWW::YoutubeViewer - A very easy interface to YouTube.
 
 =cut
 
-our $VERSION = '3.3.4';
+our $VERSION = '3.5.1';
 
 =head1 SYNOPSIS
 
@@ -68,6 +68,7 @@ my %valid_options = (
     safeSearch        => {valid => [qw(none moderate strict)], default => undef},
     videoType         => {valid => [qw(any episode movie)],    default => undef},
 
+    comments_order      => {valid => [qw(time relevance)],                default => 'time'},
     subscriptions_order => {valid => [qw(alphabetical relevance unread)], default => undef},
 
     # Others
@@ -80,6 +81,7 @@ my %valid_options = (
     # Booleans
     lwp_env_proxy => {valid => [1, 0], default => 1},
     escape_utf8   => {valid => [1, 0], default => 0},
+    prefer_mp4    => {valid => [1, 0], default => 0},
 
     # OAuth stuff
     client_id     => {valid => [qr/^.{5}/], default => undef},
@@ -338,7 +340,7 @@ sub lwp_get {
     $self->{lwp} // $self->set_lwp_useragent();
 
     my %lwp_header = ($opt{simple} ? () : $self->_get_lwp_header);
-    my $response = $self->{lwp}->get($url, %lwp_header);
+    my $response   = $self->{lwp}->get($url, %lwp_header);
 
     if ($response->is_success) {
         return $response->decoded_content;
@@ -419,20 +421,9 @@ Downloads the $url into $output_file. Returns true on success.
 =cut
 
 sub lwp_mirror {
-    my ($self, $url, $name) = @_;
-
+    my ($self, $url, $output_file) = @_;
     $self->{lwp} // $self->set_lwp_useragent();
-
-    my $response = $self->{lwp}->mirror($url, $name);
-
-    if ($response->is_success) {
-        return 1;
-    }
-    else {
-        warn '[' . $response->status_line() . "] Error occured on URL: $url\n";
-    }
-
-    return;
+    $self->{lwp}->mirror($url, $output_file);
 }
 
 sub _get_results {
@@ -649,7 +640,7 @@ sub get_streaming_urls {
 
     my $url = ($self->get_video_info_url() . sprintf($self->get_video_info_args(), $videoID));
     my $content = $self->lwp_get($url, simple => 1) // return;
-    my %info = $self->parse_query_string($content);
+    my %info    = $self->parse_query_string($content);
 
     my @streaming_urls = $self->_extract_streaming_urls(\%info, $videoID);
 
@@ -677,6 +668,27 @@ sub get_streaming_urls {
         @streaming_urls = $self->_get_formats_from_ytdl($videoID);
     }
 
+    if ($self->get_prefer_mp4) {
+
+        my @mp4_urls;
+        my @audio_urls;
+
+        foreach my $url (@streaming_urls) {
+            if ($url->{type} =~ /\bvideo\b/) {
+                if ($url->{type} =~ /\bmp4\b/) {
+                    push @mp4_urls, $url;
+                }
+            }
+            else {
+                push @audio_urls, $url;
+            }
+        }
+
+        if (@mp4_urls) {
+            @streaming_urls = (@mp4_urls, @audio_urls);
+        }
+    }
+
     return (\@streaming_urls, \@caption_urls, \%info);
 }
 
