@@ -169,7 +169,8 @@ sub normalize_video_title {
     my ($self, $title, $fat32safe) = @_;
 
     if ($fat32safe) {
-        $title =~ tr{:"*/?\\|}{;'+%$%%};    # "
+        $title =~ s/: / - /g;
+        $title =~ tr{:"*/?\\|}{;'+%!%%};    # "
         $title =~ tr/<>//d;
     }
     else {
@@ -219,30 +220,44 @@ sub format_text {
         TITLE       => sub { $self->get_title($info) },
         FTITLE      => sub { $self->normalize_video_title($self->get_title($info), $fat32safe) },
         CAPTION     => sub { $self->get_caption($info) },
+        PUBLISHED   => sub { $self->get_publication_date($info) },
         DESCRIPTION => sub { $self->get_description($info) },
 
-        RESOLUTION => sub {
-            $streaming->{resolution} =~ /^\d+\z/
-              ? $streaming->{resolution} . 'p'
-              : $streaming->{resolution};
+        RATING => sub {
+            my $likes    = $self->get_likes($info);
+            my $dislikes = $self->get_dislikes($info);
+
+            sprintf('%.2f', $likes / ($likes + $dislikes) * 5);
         },
 
-        ITAG   => sub { $streaming->{streaming}{itag} },
-        SUB    => sub { $streaming->{srt_file} },
-        VIDEO  => sub { $streaming->{streaming}{url} },
-        FORMAT => sub { $self->extension($streaming->{streaming}{type}) },
+        (
+         defined($streaming)
+         ? (
+            RESOLUTION => sub {
+                $streaming->{resolution} =~ /^\d+\z/
+                  ? $streaming->{resolution} . 'p'
+                  : $streaming->{resolution};
+            },
 
-        AUDIO => sub {
-            ref($streaming->{streaming}{__AUDIO__}) eq 'HASH'
-              ? $streaming->{streaming}{__AUDIO__}{url}
-              : q{};
-        },
+            ITAG   => sub { $streaming->{streaming}{itag} },
+            SUB    => sub { $streaming->{srt_file} },
+            VIDEO  => sub { $streaming->{streaming}{url} },
+            FORMAT => sub { $self->extension($streaming->{streaming}{type}) },
 
-        AOV => sub {
-            ref($streaming->{streaming}{__AUDIO__}) eq 'HASH'
-              ? $streaming->{streaming}{__AUDIO__}{url}
-              : $streaming->{streaming}{url};
-        },
+            AUDIO => sub {
+                ref($streaming->{streaming}{__AUDIO__}) eq 'HASH'
+                  ? $streaming->{streaming}{__AUDIO__}{url}
+                  : q{};
+            },
+
+            AOV => sub {
+                ref($streaming->{streaming}{__AUDIO__}) eq 'HASH'
+                  ? $streaming->{streaming}{__AUDIO__}{url}
+                  : $streaming->{streaming}{url};
+            },
+           )
+         : ()
+        ),
 
         URL => sub { sprintf($self->{youtube_url_format}, $self->get_video_id($info)) },
                          );
@@ -370,6 +385,35 @@ sub get_channel_id {
     $info->{snippet}{resourceId}{channelId} // $info->{snippet}{channelId};
 }
 
+sub get_category_id {
+    my ($self, $info) = @_;
+    $info->{snippet}{resourceId}{categoryId} // $info->{snippet}{categoryId};
+}
+
+sub get_category_name {
+    my ($self, $info) = @_;
+
+    state $categories = {
+                         1  => 'Film & Animation',
+                         2  => 'Autos & Vehicles',
+                         10 => 'Music',
+                         15 => 'Pets & Animals',
+                         17 => 'Sports',
+                         19 => 'Travel & Events',
+                         20 => 'Gaming',
+                         22 => 'People & Blogs',
+                         23 => 'Comedy',
+                         24 => 'Entertainment',
+                         25 => 'News & Politics',
+                         26 => 'Howto & Style',
+                         27 => 'Education',
+                         28 => 'Science & Technology',
+                         29 => 'Nonprofits & Activism',
+                        };
+
+    $categories->{$self->get_category_id($info)} // 'Unknown';
+}
+
 sub get_publication_date {
     my ($self, $info) = @_;
     $self->format_date($info->{snippet}{publishedAt});
